@@ -8,7 +8,7 @@ from .vat_charge import VatCharge, VatChargeAction
 from .vat_rules import VAT_RULES
 
 
-__version__ = '1.3.3'
+__version__ = '1.3.15'
 
 
 WHITESPACE_EXPRESSION = re.compile(r'[\s\-]+')
@@ -30,8 +30,6 @@ VAT_NUMBER_EXPRESSIONS = {
     'ES': re.compile(r'^[\da-z]\d{7}[\da-z]$', re.IGNORECASE),
     'FI': re.compile(r'^\d{8}$'),
     'FR': re.compile(r'^[\da-hj-np-z]{2}\d{9}$', re.IGNORECASE),
-    'GB': re.compile(r'^((\d{9})|(\d{12})|(GD\d{3})|(HA\d{3}))$',
-                     re.IGNORECASE),
     'GR': re.compile(r'^\d{9}$'),
     'HR': re.compile(r'^\d{11}$'),
     'HU': re.compile(r'^\d{8}$'),
@@ -42,7 +40,7 @@ VAT_NUMBER_EXPRESSIONS = {
     'LU': re.compile(r'^\d{8}$'),
     'LV': re.compile(r'^\d{11}$'),
     'MT': re.compile(r'^\d{8}$'),
-    'NL': re.compile(r'^\d{9}B\d{2,3}$', re.IGNORECASE),
+    'NL': re.compile(r'^\d{9}B\d{2}$', re.IGNORECASE),
     'PL': re.compile(r'^\d{10}$'),
     'PT': re.compile(r'^\d{9}$'),
     'RO': re.compile(r'^\d{2,10}$'),
@@ -78,7 +76,6 @@ VAT_REGISTRIES = {
     'ES': VIES_REGISTRY,
     'FI': VIES_REGISTRY,
     'FR': VIES_REGISTRY,
-    'GB': VIES_REGISTRY,
     'GR': VIES_REGISTRY,
     'HU': VIES_REGISTRY,
     'HR': VIES_REGISTRY,
